@@ -1,4 +1,3 @@
-context("Lines")
 library(xml2)
 
 test_that("segments don't have fill", {
@@ -16,7 +15,10 @@ test_that("lines don't have fill", {
     plot.new()
     lines(c(0.5, 1, 0.5), c(0.5, 1, 1))
   })
-  expect_equal(style_attr(xml_find_first(x, ".//polyline"), "fill"), NA_character_)
+  expect_equal(
+    style_attr(xml_find_first(x, ".//polyline"), "fill"),
+    NA_character_
+  )
 })
 
 test_that("polygons do have fill", {
@@ -24,7 +26,7 @@ test_that("polygons do have fill", {
     plot.new()
     polygon(c(0.5, 1, 0.5), c(0.5, 1, 1), col = "red", border = "blue")
   })
-  polygon <- xml_find_first(x, ".//polyline")
+  polygon <- xml_find_first(x, ".//polygon")
   expect_equal(style_attr(polygon, "fill"), rgb(1, 0, 0))
   expect_equal(style_attr(polygon, "stroke"), rgb(0, 0, 1))
 })
@@ -34,23 +36,14 @@ test_that("polygons without border", {
     plot.new()
     polygon(c(0.5, 1, 0.5), c(0.5, 1, 1), col = "red", border = NA)
   })
-  polygon <- xml_find_first(x, ".//polyline")
+  polygon <- xml_find_first(x, ".//polygon")
   expect_equal(style_attr(polygon, "fill"), rgb(1, 0, 0))
   expect_equal(style_attr(polygon, "stroke"), "none")
 })
 
-test_that("last point of polygon joined to first point", {
-  x <- xmlSVG({
-    plot.new()
-    polygon(c(0.5, 1, 0.5), c(0, 1, 1))
-  })
-  points <- strsplit(xml_attr(xml_find_first(x, ".//polyline"), "points"), " ")[[1]]
-  expect_equal(length(points), 4)
-})
-
 test_that("blank lines are omitted", {
   x <- xmlSVG(mini_plot(1:3, lty = "blank", type = "l"))
-  expect_equal(length(xml_find_all(x, "//polyline")), 0)
+  expect_equal(length(xml_find_all(x, "//polygon")), 0)
 })
 
 test_that("lines lty becomes stroke-dasharray", {
@@ -66,7 +59,7 @@ test_that("lines lty becomes stroke-dasharray", {
 
 test_that("stroke-dasharray scales with lwd > 1", {
   expect_equal(dash_array(lty = 2, lwd = 1), c(4, 4))
-  expect_equal(dash_array(lty = 2, lwd = 1/2), c(4, 4))
+  expect_equal(dash_array(lty = 2, lwd = 1 / 2), c(4, 4))
   expect_equal(dash_array(lty = 2, lwd = 1.1), c(4.4, 4.4))
   expect_equal(dash_array(lty = 2, lwd = 2), c(8, 8))
 })
@@ -86,9 +79,18 @@ test_that("line end shapes", {
   })
   style <- xml_text(xml_find_first(x1, "//style"))
   expect_match(style, "stroke-linecap: round;")
-  expect_equal(style_attr(xml_find_first(x1, ".//polyline"), "stroke-linecap"), NA_character_)
-  expect_equal(style_attr(xml_find_first(x2, ".//polyline"), "stroke-linecap"), "butt")
-  expect_equal(style_attr(xml_find_first(x3, ".//polyline"), "stroke-linecap"), "square")
+  expect_equal(
+    style_attr(xml_find_first(x1, ".//polyline"), "stroke-linecap"),
+    NA_character_
+  )
+  expect_equal(
+    style_attr(xml_find_first(x2, ".//polyline"), "stroke-linecap"),
+    "butt"
+  )
+  expect_equal(
+    style_attr(xml_find_first(x3, ".//polyline"), "stroke-linecap"),
+    "square"
+  )
 })
 
 test_that("line join shapes", {
@@ -98,11 +100,23 @@ test_that("line join shapes", {
   })
   x2 <- xmlSVG({
     plot.new()
-    lines(c(0.3, 0.5, 0.7), c(0.1, 0.9, 0.1), lwd = 15, ljoin = "mitre", lmitre = 10)
+    lines(
+      c(0.3, 0.5, 0.7),
+      c(0.1, 0.9, 0.1),
+      lwd = 15,
+      ljoin = "mitre",
+      lmitre = 10
+    )
   })
   x3 <- xmlSVG({
     plot.new()
-    lines(c(0.3, 0.5, 0.7), c(0.1, 0.9, 0.1), lwd = 15, ljoin = "mitre", lmitre = 4)
+    lines(
+      c(0.3, 0.5, 0.7),
+      c(0.1, 0.9, 0.1),
+      lwd = 15,
+      ljoin = "mitre",
+      lmitre = 4
+    )
   })
   x4 <- xmlSVG({
     plot.new()
@@ -111,10 +125,28 @@ test_that("line join shapes", {
   style <- xml_text(xml_find_first(x1, "//style"))
   expect_match(style, "stroke-linejoin: round;")
   expect_match(style, "stroke-miterlimit: 10.00;")
-  expect_equal(style_attr(xml_find_all(x1, ".//polyline"), "stroke-linejoin"), NA_character_)
-  expect_equal(style_attr(xml_find_all(x2, ".//polyline"), "stroke-linejoin"), "miter")
-  expect_equal(style_attr(xml_find_all(x2, ".//polyline"), "stroke-miterlimit"), NA_character_)
-  expect_equal(style_attr(xml_find_all(x3, ".//polyline"), "stroke-linejoin"), "miter")
-  expect_equal(style_attr(xml_find_all(x3, ".//polyline"), "stroke-miterlimit"), "4.00")
-  expect_equal(style_attr(xml_find_all(x4, ".//polyline"), "stroke-linejoin"), "bevel")
+  expect_equal(
+    style_attr(xml_find_all(x1, ".//polyline"), "stroke-linejoin"),
+    NA_character_
+  )
+  expect_equal(
+    style_attr(xml_find_all(x2, ".//polyline"), "stroke-linejoin"),
+    "miter"
+  )
+  expect_equal(
+    style_attr(xml_find_all(x2, ".//polyline"), "stroke-miterlimit"),
+    NA_character_
+  )
+  expect_equal(
+    style_attr(xml_find_all(x3, ".//polyline"), "stroke-linejoin"),
+    "miter"
+  )
+  expect_equal(
+    style_attr(xml_find_all(x3, ".//polyline"), "stroke-miterlimit"),
+    "4.00"
+  )
+  expect_equal(
+    style_attr(xml_find_all(x4, ".//polyline"), "stroke-linejoin"),
+    "bevel"
+  )
 })
